@@ -2,10 +2,12 @@ library(RSQL)
 rsql <- createRSQL(drv = RSQLite::SQLite(), dbname = db.name)
 
 where.accent <- "áccent"
-#where.accent <- "Bélgica"
+# where.accent <- "Bélgica"
 where.df <- data.frame(model = where.accent, stringsAsFactors = FALSE)
-exists.sql <- rsql$gen_select("id_pais", table = "pais",
-                              where_values = where.df)
+exists.sql <- rsql$gen_select("id_pais",
+  table = "pais",
+  where_values = where.df
+)
 exists.sql
 re_quote(where.accent)
 re_quote(text.df)
